process GET_ALIGNMENT_METRICS {
   tag "${meta.id}"
   publishDir "${params.outdir}/$publishDir_path/${meta.id}", mode: 'copy'

   input:
      tuple val(meta), path(bam), path(bai)
      val(publishDir_path)

   output:
      tuple val(meta), path("${meta.id}.coverage.tsv"), emit: sam_coverage
      tuple val(meta), path("${meta.id}.idxstats"), emit: sam_idxstat
      path "${meta.id}.flagstat", emit: sam_flagstat
      path "${meta.id}*"
      path "v_samtools.txt", emit: v_samtools

   script:
      """
      samtools flagstat -@ ${task.cpus}  ${bam} > ${meta.id}.flagstat
      samtools coverage  ${bam} > ${meta.id}.coverage.tsv
      samtools idxstats ${bam} > ${meta.id}.idxstats

      samtools --version &> v_samtools.txt
      """
}


process FILTER_BAM {
   tag "${meta.id}"

   input:
      tuple val(meta),  path(discarded_contigs), path(bam), path(bai)

   output:
      tuple val(meta), path("selected_contigs.bam"), emit: selected_contigs_bam
      tuple val(meta), path("discarded_contigs.bam"), emit: discarded_contigs_bam


   script:
      """
      
      samtools faidx $discarded_contigs 
      awk 'BEGIN {FS="\\t"}; {print \$1 FS "0" FS \$2}' ${discarded_contigs}.fai > discarded_contigs.bed


      samtools view -@ ${task.cpus}  -bL discarded_contigs.bed -U selected_contigs.bam  $bam  -o discarded_contigs.bam


      """
}

process EXTRACT_PAIRED_READS {
   tag "${meta.id}"

   input:
      tuple val(meta),  path(bam)

   output:
      tuple val(meta), path("reads*.fastq.gz"), emit: reads


   script:
      """
      
      samtools fastq -@ ${task.cpus}  -N  -1 reads_R1.fastq.gz -2 reads_R2.fastq.gz $bam

      """
}

process EXTRACT_SINGLE_READS {
   tag "${meta.id}"

   input:
      tuple val(meta),  path(bam)

   output:
      tuple val(meta), path("reads.fastq.gz"), emit: reads

   script:
      """
      
      samtools fastq -@ ${task.cpus} -o reads.fastq.gz $bam

      """
}



process MERGE_BAM_FILES {
   tag "${meta.id}"

   input:
      tuple val(meta),  path(bam_discarded_reads), path(bam_selected_contigs)

   output:
      tuple val(meta), path("${meta.id}.filtered.sort.bam"), path("${meta.id}.filtered.sort.bam.bai") , emit: bam

   script:

      """  
      samtools merge -@ ${task.cpus} $bam_discarded_reads $bam_selected_contigs -o merged.bam

      # reheader the bam to get only header corresponding to the final assembly only 
      samtools view -H  $bam_discarded_reads > filtered_assembly.header
      samtools reheader filtered_assembly.header merged.bam | samtools sort -@ ${task.cpus} -o ${meta.id}.filtered.sort.bam  
      
      samtools index -@ ${task.cpus} ${meta.id}.filtered.sort.bam

      rm merged.bam 
      """
}

