include { METASPADES; MEGAHIT; HIFIASM_META; METAFLYE; RENAME_CONTIGS } from '../modules/assembly'
include { QUAST as ASSEMBLY_QUAST} from '../modules/metaquast'
include { READS_DEDUPLICATION } from '../modules/reads_deduplication'
include { MINIMAP2 } from '../modules/read_alignment'
include { GET_ALIGNMENT_METRICS } from '../modules/read_alignment_manipulation'

workflow STEP_02_ASSEMBLY {
  take: 
    reads
    assembly
    has_assembly
    assembly_tool

  main:
    ch_assembler_v = Channel.empty() 
    ch_quast_v = Channel.empty()
    ch_bwa_mem_v = Channel.empty()
    ch_minimap2_v = Channel.empty()
    ch_samtools_v = Channel.empty()
  
    if (has_assembly){
      ch_assembly = assembly   
    } 
    else {
      if(assembly_tool == 'metaspades') {
        METASPADES(reads)
        ch_assembly = METASPADES.out.assembly
        ch_assembler_v = METASPADES.out.v_metaspades
      } 
      else if(assembly_tool == 'megahit') {
        MEGAHIT(reads)
        ch_assembly = MEGAHIT.out.assembly
        ch_assembler_v = MEGAHIT.out.v_megahit
      } 
      else if(assembly_tool == 'hifiasm-meta') {
        HIFIASM_META(reads)
        ch_assembly = HIFIASM_META.out.assembly
        ch_assembler_v = HIFIASM_META.out.v_hifiasm_meta
        } 
      else if(assembly_tool == 'metaflye') {
          METAFLYE(reads)
          ch_assembly = METAFLYE.out.assembly
          ch_assembler_v = METAFLYE.out.v_metaflye
        } 
      else {
        exit 1,  "Invalid assembly parameter: ${assembly_tool}"
        }
    }
    
    ch_assembly_renamed = RENAME_CONTIGS(ch_assembly)
    ASSEMBLY_QUAST( ch_assembly_renamed,"02_assembly/02_1_primary_assembly/assembly_metric/")
    ch_assembly_report = ASSEMBLY_QUAST.out.report
    ch_quast_v = ASSEMBLY_QUAST.out.v_quast

    ch_idxstats = Channel.empty()
    ch_flagstat = Channel.empty()
    ch_reads = reads

    ch_contigs_and_reads = ch_assembly_renamed.join(ch_reads, remainder: true)
    if ( params.type.toUpperCase() == "SR" ) {

      READS_DEDUPLICATION ( ch_contigs_and_reads )
      
      ch_reads = READS_DEDUPLICATION.out.dedup_reads
      ch_bam = READS_DEDUPLICATION.out.bam

      ch_bwa_mem_v = READS_DEDUPLICATION.out.v_bwa_mem2
      
    } else {
        MINIMAP2(ch_contigs_and_reads,"02_assembly/02_3_reads_vs_primary_assembly")
        ch_bam = MINIMAP2.out.bam

        ch_minimap2_v = MINIMAP2.out.v_minimap2
        
    }

    GET_ALIGNMENT_METRICS(ch_bam, "02_assembly/02_3_reads_vs_primary_assembly")

    ch_idxstats  = GET_ALIGNMENT_METRICS.out.sam_idxstat
    ch_flagstat =  GET_ALIGNMENT_METRICS.out.sam_flagstat
    ch_coverage =  GET_ALIGNMENT_METRICS.out.sam_coverage
    ch_samtools_v = GET_ALIGNMENT_METRICS.out.v_samtools

    ch_software_versions = ch_assembler_v.first().mix( ch_quast_v.first(),
                                                       ch_bwa_mem_v.first(),
                                                       ch_minimap2_v.first(),
                                                       ch_samtools_v.first())


  emit:
    assembly = ch_assembly_renamed
    reads = ch_reads
    bam = ch_bam

    idxstats = ch_idxstats
    flagstat = ch_flagstat
    coverage = ch_coverage
    assembly_report = ch_assembly_report
    software_versions = ch_software_versions
}