include { CHUNK_ASSEMBLY_FILTER; MERGE_ASSEMBLY_FILTER} from '../modules/filtering_cpm.nf'
include { QUAST } from '../modules/metaquast'
include { MINIMAP2; BWA_MEM } from '../modules/read_alignment'
include { GET_ALIGNMENT_METRICS; FILTER_BAM; EXTRACT_SINGLE_READS; EXTRACT_PAIRED_READS; MERGE_BAM_FILES} from '../modules/read_alignment_manipulation'

workflow STEP_03_ASSEMBLY_FILTER {
  take:
    assemblies
    idxstats
    bam
    min_cpm

  main:
    ch_chunk_assembly_for_filter = assemblies
                                  .splitFasta(by: 100000, file: true)
  

    ch_assembly_and_idxstats = ch_chunk_assembly_for_filter
                                .combine(idxstats, by:0)

    CHUNK_ASSEMBLY_FILTER (
      ch_assembly_and_idxstats,
      min_cpm
    )
    ch_chunk_selected =  CHUNK_ASSEMBLY_FILTER.out.chunk_selected
    ch_chunk_discarded = CHUNK_ASSEMBLY_FILTER.out.chunk_discarded

    ch_chunk_selected
      .groupTuple(by: 0)
      .set{ ch_grouped_selected }

    ch_chunk_discarded
      .groupTuple(by: 0)
      .set{ ch_grouped_discarded }

    MERGE_ASSEMBLY_FILTER (
      ch_grouped_selected,
      ch_grouped_discarded,
      min_cpm
    )
    ch_merged_selected = MERGE_ASSEMBLY_FILTER.out.merged_selected
    discarded_contigs = MERGE_ASSEMBLY_FILTER.out.merged_discarded


   // Differentiate sample with and without discarded_contigs 
   // samples with no discarded_contigs are not going to be processed to process 
   discarded_contigs_category = discarded_contigs.branch{
                              without: it[1].isEmpty() 
                              with: !it[1].isEmpty() 
                              }


   samples_without_discarded_contigs = discarded_contigs_category.without.map{ it -> it[0]}
   ch_bam_of_sample_without_discarded_contigs = samples_without_discarded_contigs.join(bam)
   
  ch_discarded_contigs_and_bam = discarded_contigs_category.with.join(bam)

  FILTER_BAM(ch_discarded_contigs_and_bam)

  ch_discarded_bam = FILTER_BAM.out.discarded_contigs_bam
  ch_selected_bam = FILTER_BAM.out.selected_contigs_bam 

  if ( params.type.toUpperCase() == "SR" ) {
        
        ch_discarded_reads = EXTRACT_PAIRED_READS(ch_discarded_bam)

        ch_contigs_and_discarded_reads = ch_merged_selected.join(ch_discarded_reads) 

        BWA_MEM(ch_contigs_and_discarded_reads, "03_filtering/03_2_reads_vs_filtered_assembly")
        ch_bam_with_discarded_reads = BWA_MEM.out.bam

  } else {
        ch_discarded_reads = EXTRACT_SINGLE_READS(ch_discarded_bam)
        ch_contigs_and_discarded_reads = ch_merged_selected.join(ch_discarded_reads) 
        MINIMAP2(ch_contigs_and_discarded_reads, "03_filtering/03_2_reads_vs_filtered_assembly")
        ch_bam_with_discarded_reads = MINIMAP2.out.bam
  
  }


   // remove bai from ch_bam_with_discarded_reads and add bam of selected contigs
  ch_bam_to_merge = ch_bam_with_discarded_reads.map{ it -> [it[0], it[1]]}.join(ch_selected_bam)

  ch_merged_bam = MERGE_BAM_FILES(ch_bam_to_merge)

   ch_final_bam = ch_bam_of_sample_without_discarded_contigs.mix(ch_merged_bam)


  GET_ALIGNMENT_METRICS(ch_final_bam, '03_filtering/03_2_reads_vs_filtered_assembly/')

  ch_flagstat =  GET_ALIGNMENT_METRICS.out.sam_flagstat
  ch_coverage =  GET_ALIGNMENT_METRICS.out.sam_coverage

  QUAST( ch_merged_selected, "03_filtering/03_1_filtered_assembly/assembly_metric" )
  ch_quast_report = QUAST.out.report

  emit:
    selected_contigs = ch_merged_selected
    quast_report = ch_quast_report
    bam = ch_final_bam
    sam_coverage = ch_coverage
    sam_flagstat = ch_flagstat

}

