include { GENERATE_DEPTH_FILES; METABAT2; MAXBIN2; CONCOCT; METAWRAP_REFINMENT; UNBINNED_CONTIGS } from '../modules/binning'
include { CHECKM2 } from '../modules/checkm2'
include { DREP } from '../modules/drep'
include { BWA_MEM;BWA_MEM as BWA_MEM_CROSS_ALIGNMENT; MINIMAP2; MINIMAP2 as MINIMAP2_CROSS_ALIGNMENT } from '../modules/read_alignment'
include { GET_ALIGNMENT_METRICS } from '../modules/read_alignment_manipulation'
include { GTDBTK } from '../modules/gtdbtk'
include { GENOMES_ABUNDANCES_PER_SAMPLE; ADD_QUAST_INFO_TO_BINS; BINS_STATS_TO_MUTLIQC_FORMAT} from '../modules/sum_up_bins_informations'

// Declare syntax version
nextflow.enable.dsl=2
// Script parameters

workflow STEP_08_BINNING {
  take: reads
  assembly
  bam
  gtdbtk_db
  quast

  main:

  ch_bwa_mem_v = Channel.empty()
  ch_minimap2_v = Channel.empty()
  ch_samtools_v = Channel.empty()
  ch_metabat2_v = Channel.empty()
  ch_maxbin_v = Channel.empty()
  ch_concoct_v = Channel.empty()
  ch_metawrap_v = Channel.empty()
  ch_checkm2_v = Channel.empty()
  ch_dRep_v = Channel.empty()
  ch_gtdbtk_v = Channel.empty()
  ch_bins_abundances_report = Channel.empty()
  ch_bins_stats_report = Channel.empty()
  ch_metabat_bins = Channel.empty()
  ch_maxbin_bins = Channel.empty()
  ch_concoct_bins = Channel.empty()


  ////// 
  /// Config
  //////
  ch_heatmap_header_multiqc = file("$projectDir/assets/multiqc/bins_abundances_header.txt", checkIfExists: true)
  ch_barplot_bin_count_header_multiqc = file("$projectDir/assets/multiqc/barplot_bin_count_header.txt", checkIfExists: true)
  ch_barplot_bin_size_header_multiqc = file("$projectDir/assets/multiqc/barplot_bin_size_header.txt", checkIfExists: true)
  ch_table_header_multiqc = file("$projectDir/assets/multiqc/bin_stats_table_header.txt", checkIfExists: true)
  
  ////// 
  /// CROSS ALIGNMENT 
  //////

  if (params.binning_cross_alignment != 'individual'){
    if (params.binning_cross_alignment == 'all') {
      // combine assemblies with reads of all samples
      ch_reads_assembly = reads.combine(assembly)
      .map{ meta_reads, reads, meta_assembly, assembly ->
        if (meta_reads != meta_assembly){
          [[id:meta_reads.id+"_"+meta_assembly.id, sample:meta_assembly.sample, flowcell:meta_assembly.flowcell, group:meta_assembly.group, assembly:meta_assembly.assembly, type:meta_assembly.type], assembly, reads]
        }
      }
    } else if (params.binning_cross_alignment == 'group'){
      // combine assemblies with reads of samples from same group
      ch_assembly_group = assembly.map{ meta, assembly -> [ meta.group, meta, assembly ] }
      ch_reads_assembly = reads.map{ meta, reads -> [ meta.group, meta, reads ] }
      .combine(ch_assembly_group, by: 0)
      .map{ group, meta_reads, reads, meta_assembly, assembly ->
        if (meta_reads != meta_assembly){
          [[id:meta_reads.id+"_"+meta_assembly.id, sample:meta_assembly.sample, flowcell:meta_assembly.flowcell, group:meta_assembly.group, assembly:meta_assembly.assembly, type:meta_assembly.type], assembly, reads]
        }
      }
    }
    // cross alignment
    if (params.type == 'SR') {
      BWA_MEM_CROSS_ALIGNMENT(ch_reads_assembly,"08_binning/08_1_binning_per_sample/cross_mapping")
      ch_bam_cross_alignment = BWA_MEM_CROSS_ALIGNMENT.out.bam
    } else {
      MINIMAP2_CROSS_ALIGNMENT(ch_reads_assembly,"08_binning/08_1_binning_per_sample/cross_mapping")
      ch_bam_cross_alignment = MINIMAP2_CROSS_ALIGNMENT.out.bam
    } 
    // formatting channel  
    ch_bam = ch_bam_cross_alignment.mix(bam)
    .map { meta, bam, bai -> [ meta.sample, meta, bam, bai ]  }
    .groupTuple(by: [0])
    .map { sample,metas, bam, bai ->
      [ metas.min { it.id.size() }, bam, bai ]
    } 
  } else {
      ch_bam = bam
  }

  ///////////
  /// BINNING
  ///////////

  ch_depth = GENERATE_DEPTH_FILES(ch_bam)
  ch_assembly_depth = assembly.join(ch_depth)

  METABAT2(ch_assembly_depth)
  ch_metabat_bins = METABAT2.out.bins.filter{ t -> t[1].list().size()}
  ch_metabat2_v = METABAT2.out.v_metabat2

  MAXBIN2(ch_assembly_depth)
  ch_maxbin_bins = MAXBIN2.out.bins.filter{ t -> t[1].list().size()}
  ch_maxbin_v = MAXBIN2.out.v_maxbin

  ch_assembly_bam = assembly.join(ch_bam)

  CONCOCT(ch_assembly_bam)
  ch_concoct_bins = CONCOCT.out.bins.filter{ t -> t[1].list().size()}
  ch_concoct_v = CONCOCT.out.v_concoct


  //////////////////
  //// BIN REFINEMENT  
  //////////////////
  ch_bins_set = ch_metabat_bins.join(ch_concoct_bins, remainder:true)
  .join(ch_maxbin_bins, remainder:true)
  .branch{
      multiple: (it[1] != null && it[2] != null) || 
      (it[1] != null && it[3] != null) ||
      (it[2] != null && it[3] != null)
      single: true
      }

  ch_bins_multiple = ch_bins_set.multiple.map{ meta, bins1, bins2, bins3 -> 
    if ( bins1 == null ) {
      return [meta, bins2, bins3, bins1]
    } else if ( bins2 == null ) { 
      return [meta, bins1, bins3, bins2]
    } else { 
      return [meta, bins1, bins2, bins3]
    }
  }

  ch_bins_single = ch_bins_set.single.map{ meta, bins1, bins2, bins3 -> 
    if ( bins1 != null ) {
      return [meta, bins1]
    } else if ( bins2 != null ) { 
      return [meta, bins2]
    } else { 
      return [meta, bins3]
    }
  }

  CHECKM2(ch_bins_single)
  ch_checkm2_v = CHECKM2.out.v_checkm2


  ch_all_bins_stats = Channel.empty()
  ch_metawrap_stats_and_quast = Channel.empty()
  ch_metawrap_bins = Channel.empty()
  ch_metawrap_bins = Channel.empty()
  ch_metawrap_stats_and_quast = Channel.empty()
  ch_bins_assembly = Channel.empty()

  METAWRAP_REFINMENT(ch_bins_multiple, params.min_completeness, params.max_contamination)
  ch_metawrap_bins = METAWRAP_REFINMENT.out.bins
                                           .map { meta, file -> file}
                                           .collect()
  ch_metawrap_stats = METAWRAP_REFINMENT.out.checkm_stats
                                            .map { meta, file -> file}
                                            .collect()
  
  ch_bins_assembly = METAWRAP_REFINMENT.out.bins.join(assembly)

  UNBINNED_CONTIGS(ch_bins_assembly)

  ch_metawrap_stats_and_quast =  METAWRAP_REFINMENT.out.checkm_stats.join(quast) 
  ch_metawrap_v = METAWRAP_REFINMENT.out.v_metawrap
  
  ADD_QUAST_INFO_TO_BINS(ch_metawrap_stats_and_quast)
  
  ch_all_bins_stats = ADD_QUAST_INFO_TO_BINS.out.bins_stats.collect()

  BINS_STATS_TO_MUTLIQC_FORMAT(ch_all_bins_stats, 
                                  ch_barplot_bin_count_header_multiqc, 
                                  ch_barplot_bin_size_header_multiqc)
  ch_bins_stats_report = BINS_STATS_TO_MUTLIQC_FORMAT.out.report
  
  ////////////////////////
  ///// DEREPLICATION BIN 
  ////////////////////////

  ch_bins_drep = Channel.empty()
  
  DREP(ch_metawrap_stats, ch_metawrap_bins, params.drep_threshold)
  ch_bins_drep = DREP.out.drep_bins_folder
  ch_dRep_v = DREP.out.v_dRep

  ///////////////////////////////
  ///// TAXONOMIC AFFILIATION BIN
  /////////////////////////////// 

  GTDBTK(ch_bins_drep, gtdbtk_db)
  ch_gtdbtk_v = GTDBTK.out.v_gtdbtk

  /////////////////////////////
  ////GENOMES ABUNDANCES
  /////////////////////////////
  ch_reads_fna = reads.combine(DREP.out.fna)
                .map { meta, reads, bins -> [meta, bins, reads] }

  if (params.type == 'SR') {
    BWA_MEM(ch_reads_fna, "08_binning/08_4_mapping_on_final_bins/mapping")
    ch_bam = BWA_MEM.out.bam
    ch_bwa_mem_v = BWA_MEM.out.v_bwa_mem2
    ch_samtools_v = BWA_MEM.out.v_samtools
  } else {
    MINIMAP2(ch_reads_fna, "08_binning/08_4_mapping_on_final_bins/mapping")
    ch_bam = MINIMAP2.out.bam
    ch_minimap2_v = MINIMAP2.out.v_minimap2
    ch_samtools_v = MINIMAP2.out.v_samtools
  }

  ch_collect_coverages = Channel.empty()
  ch_collect_flagstats = Channel.empty()
  GET_ALIGNMENT_METRICS(ch_bam, "08_binning/08_4_mapping_on_final_bins/stats")

  ch_collect_coverages = GET_ALIGNMENT_METRICS.out.sam_coverage.map {id, file -> file}
              .collect()
  ch_collect_flagstats = GET_ALIGNMENT_METRICS.out.sam_flagstat.collect()

  GENOMES_ABUNDANCES_PER_SAMPLE(ch_collect_coverages, ch_collect_flagstats, \
   ch_bins_drep, DREP.out.output_drep_stats, GTDBTK.out.gtdbtk_affiliations_predictions,
   ch_heatmap_header_multiqc, ch_table_header_multiqc)

  ch_bins_abundances_report = GENOMES_ABUNDANCES_PER_SAMPLE.out.report

  ch_software_versions = ch_bwa_mem_v.first().mix(ch_minimap2_v.first(),
                                                  ch_samtools_v.first(),
                                                  ch_metabat2_v.first(),
                                                  ch_maxbin_v.first(),
                                                  ch_concoct_v.first(),
                                                  ch_metawrap_v,
                                                  ch_checkm2_v.first(),
                                                  ch_dRep_v,
                                                  ch_gtdbtk_v,
                                                  )

  emit:
    bins_abundances_report = ch_bins_abundances_report
    bins_stats_report = ch_bins_stats_report
    software_versions = ch_software_versions

}
